# Third-Party Notices

This file is generated from dependency metadata.

- Generated at: 2026-02-07 18:02:20Z
- Python: 3.13.12
- Platform: Linux-6.3.0-060300-generic-x86_64-with-glibc2.35
- Source: `pyproject.toml`
- Selected extras: `sym,plot,speed,jax`

## Inventory

| Package | Version | License | Home page | Status |
|---|---:|---|---|---|
| contourpy | 1.3.3 | BSD 3-Clause License Copyright (c) 2021-2025, ContourPy Developers. All rights reserved. Redistribution and use in so... | https://github.com/contourpy/contourpy | installed |
| cycler | 0.12.1 | Copyright (c) 2015, matplotlib project All rights reserved. Redistribution and use in source and binary forms, with o... | https://matplotlib.org/cycler/ | installed |
| fonttools | 4.61.1 | MIT | http://github.com/fonttools/fonttools | installed |
| kiwisolver | 1.4.9 | ========================= The Kiwi licensing terms ========================= Kiwi is licensed under the terms of the ... | https://github.com/nucleic/kiwi | installed |
| llvmlite | 0.46.0 | UNKNOWN | http://llvmlite.readthedocs.io | installed |
| matplotlib | 3.10.8 | License agreement for matplotlib versions 1.3.0 and later ========================================================= 1... | https://matplotlib.org | installed |
| mpmath | 1.3.0 | BSD | http://mpmath.org/ | installed |
| numba | 0.63.1 | BSD | https://numba.pydata.org | installed |
| numpy | 2.3.5 | Copyright (c) 2005-2025, NumPy Developers. All rights reserved. Redistribution and use in source and binary forms, wi... | https://numpy.org | installed |
| packaging | 26.0 | UNKNOWN | https://packaging.pypa.io/ | installed |
| pandas | 3.0.0 | BSD 3-Clause License Copyright (c) 2008-2011, AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Developmen... | https://pandas.pydata.org | installed |
| pillow | 12.1.0 | UNKNOWN | https://github.com/python-pillow/Pillow/releases | installed |
| pyparsing | 3.3.2 | UNKNOWN | https://pyparsing-docs.readthedocs.io/en/latest/ | installed |
| python-dateutil | 2.9.0.post0 | Dual License | https://github.com/dateutil/dateutil | installed |
| scipy | 1.17.0 | Copyright (c) 2001-2002 Enthought, Inc. 2003, SciPy Developers. All rights reserved. Redistribution and use in source... | https://scipy.org/ | installed |
| six | 1.17.0 | MIT | https://github.com/benjaminp/six | installed |
| sympy | 1.14.0 | BSD | https://sympy.org | installed |
| jax | - | - | - | missing |
| jaxlib | - | - | - | missing |

## Notes

- License/homepage values come from package metadata and may be incomplete.
- `missing` means declared in selected dependency closure but not installed in the current environment.
